==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppRelayServiceConnection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppRelayServiceConnection].
 */
@PulumiTagMarker
public class WebAppRelayServiceConnectionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppRelayServiceConnectionArgs = WebAppRelayServiceConnectionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppRelayServiceConnectionArgsBuilder.() -> Unit) {
        val builder = WebAppRelayServiceConnectionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebAppRelayServiceConnection {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppRelayServiceConnection(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppRelayServiceConnection(builtJavaResource)
    }
}

/**
 * Hybrid Connection for an App Service app.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppRelayServiceConnection myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/hybridconnection/{entityName}
 * ```
 */
public class WebAppRelayServiceConnection internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppRelayServiceConnection,
) : KotlinCustomResource(javaResource, WebAppRelayServiceConnectionMapper) {
    public val biztalkUri: Output<String>?
        get() = javaResource.biztalkUri().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val entityConnectionString: Output<String>?
        get() = javaResource.entityConnectionString().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val entityName: Output<String>?
        get() = javaResource.entityName().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val hostname: Output<String>?
        get() = javaResource.hostname().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    public val port: Output<Int>?
        get() = javaResource.port().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    public val resourceConnectionString: Output<String>?
        get() = javaResource.resourceConnectionString().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val resourceType: Output<String>?
        get() = javaResource.resourceType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppRelayServiceConnectionMapper : ResourceMapper<WebAppRelayServiceConnection> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppRelayServiceConnection::class == javaResource::class

    override fun map(javaResource: Resource): WebAppRelayServiceConnection =
        WebAppRelayServiceConnection(
            javaResource as
                com.pulumi.azurenative.web.WebAppRelayServiceConnection,
        )
}

/**
 * @see [WebAppRelayServiceConnection].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppRelayServiceConnection].
 */
public suspend fun webAppRelayServiceConnection(
    name: String,
    block: suspend WebAppRelayServiceConnectionResourceBuilder.() -> Unit,
):
    WebAppRelayServiceConnection {
    val builder = WebAppRelayServiceConnectionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppRelayServiceConnection].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppRelayServiceConnection(name: String): WebAppRelayServiceConnection {
    val builder = WebAppRelayServiceConnectionResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppRelayServiceConnection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppRelayServiceConnection].
 */
@PulumiTagMarker
public class WebAppRelayServiceConnectionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppRelayServiceConnectionArgs = WebAppRelayServiceConnectionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppRelayServiceConnectionArgsBuilder.() -> Unit) {
        val builder = WebAppRelayServiceConnectionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppRelayServiceConnection {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppRelayServiceConnection(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppRelayServiceConnection(builtJavaResource)
    }
}

/**
 * Hybrid Connection for an App Service app.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppRelayServiceConnection myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/hybridconnection/{entityName}
 * ```
 */
public class WebAppRelayServiceConnection internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppRelayServiceConnection,
) : KotlinCustomResource(javaResource, WebAppRelayServiceConnectionMapper) {
    public val biztalkUri: Output<String>?
        get() = javaResource.biztalkUri().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val entityConnectionString: Output<String>?
        get() = javaResource.entityConnectionString().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val entityName: Output<String>?
        get() = javaResource.entityName().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val hostname: Output<String>?
        get() = javaResource.hostname().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    public val port: Output<Int>?
        get() = javaResource.port().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    public val resourceConnectionString: Output<String>?
        get() = javaResource.resourceConnectionString().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    public val resourceType: Output<String>?
        get() = javaResource.resourceType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppRelayServiceConnectionMapper : ResourceMapper<WebAppRelayServiceConnection> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppRelayServiceConnection::class == javaResource::class

    override fun map(javaResource: Resource): WebAppRelayServiceConnection =
        WebAppRelayServiceConnection(
            javaResource as
                com.pulumi.azurenative.web.WebAppRelayServiceConnection,
        )
}

/**
 * @see [WebAppRelayServiceConnection].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppRelayServiceConnection].
 */
public suspend fun webAppRelayServiceConnection(
    name: String,
    block: suspend WebAppRelayServiceConnectionResourceBuilder.() -> Unit,
):
    WebAppRelayServiceConnection {
    val builder = WebAppRelayServiceConnectionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppRelayServiceConnection].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppRelayServiceConnection(name: String): WebAppRelayServiceConnection {
    val builder = WebAppRelayServiceConnectionResourceBuilder()
    builder.name(name)
    return builder.build()
}
